pydeflate package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pydeflate.deflate
   pydeflate.get_data
   pydeflate.tools

Submodules
----------

pydeflate.config module
-----------------------

.. automodule:: pydeflate.config
   :members:
   :undoc-members:
   :show-inheritance:

pydeflate.utils module
----------------------

.. automodule:: pydeflate.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pydeflate
   :members:
   :undoc-members:
   :show-inheritance:
